#!/usr/bin/env python3

import importlib.util
import os
import os.path
import shutil
import subprocess
import sys

this_dir = os.path.abspath(os.path.dirname(__file__) or ".")

def version(build_it):
    return "4.2.15"

def install(build_it):
    zip_ = "hdf-4.2.15.tar.gz"
    src_dir = "hdf-4.2.15"
    if os.path.isdir(src_dir):
        shutil.rmtree(src_dir)
    build_it.extract_file(zip_)
    os.chdir(src_dir)
    patch_dir = os.path.join(this_dir, "patches")
    with open(os.path.join(patch_dir, "hdfi.h.patch"), 'r') as patch_h:
        subprocess.check_call(["patch", "-b", "-p0"], stdin=patch_h)
    with open(os.path.join(patch_dir, "hlimits.h.patch"), 'r') as patch_h:
        subprocess.check_call(["patch", "-b", "-p0"], stdin=patch_h)

    os.environ["CFLAGS"] = "-I%s/include %s" % (os.environ["LIB3_DIR"], os.environ["CFLAGS"])
    os.environ["LDFLAGS"] = "-L%s/lib %s" % (os.environ["LIB3_DIR"], os.environ["LDFLAGS"])

    # save ncdump
    ncdumpPath = os.environ["LIB3_DIR"] + "/bin/ncdump"
    ncgenPath = os.environ["LIB3_DIR"] + "/bin/ncgen"
    if os.path.exists(ncdumpPath):
        shutil.move(ncdumpPath, ncdumpPath+".good")
    if os.path.exists(ncgenPath):
        shutil.move(ncgenPath, ncgenPath+".good")

    subprocess.check_call(["./configure", "--prefix", build_it.opt_dir, "--enable-shared", "--disable-fortran", "--disable-netcdf", "--enable-hdf4-xdr"])

    subprocess.check_call(["make"])
    #subprocess.check_call(["make", "test"])
    subprocess.check_call(["make", "install"])

    # rename and restore ncdump
    shutil.move(ncdumpPath, ncdumpPath+"_hdf")
    if os.path.exists(ncdumpPath+".good"):
        shutil.move(ncdumpPath+".good", ncdumpPath)
    shutil.move(ncgenPath, ncgenPath+"_hdf")
    if os.path.exists(ncgenPath+".good"):
        shutil.move(ncgenPath+".good", ncgenPath)

    os.chdir(this_dir)

    if not os.environ['OCSSW_DEBUG'] or os.environ['OCSSW_DEBUG'] == "0":
        shutil.rmtree(src_dir)

if __name__ == "__main__":
    os.chdir(this_dir)

    spec = importlib.util.spec_from_file_location("BuildIt", os.path.join("..", "BuildIt.py"))
    build_it = importlib.util.module_from_spec(spec)
    spec.loader.exec_module(build_it)
    master = build_it.BuildIt()
    master.setup_environment()
    sys.exit(install(master))
